Roll skia and change SK_SUPPORT_GPU -> SK_GANESH

https://skia.googlesource.com/skia.git/+log/a13d52c7aaa8..f9c77b544

Follow-up to https://skia-review.googlesource.com/c/skia/+/650116

Change-Id: Ib67d751055a1d884dfa0e6c36864846b6d01865f
Reviewed-on: https://pdfium-review.googlesource.com/c/pdfium/+/104210
Reviewed-by: Lei Zhang <thestig@chromium.org>
Commit-Queue: Lei Zhang <thestig@chromium.org>
Auto-Submit: Kevin Lubick <kjlubick@google.com>
Reviewed-by: Ben Wagner <bungeman@google.com>
diff --git a/DEPS b/DEPS
index 5d93cee..c891c81 100644
--- a/DEPS
+++ b/DEPS
@@ -148,7 +148,7 @@
   # Three lines of non-changing comments so that
   # the commit queue can handle CLs rolling skia
   # and whatever else without interference from each other.
-  'skia_revision': 'a13d52c7aaa842ddc9cea34f779561152bbeff78',
+  'skia_revision': 'f9c77b544bbf313749ca5949c85048f500990a3c',
   # Three lines of non-changing comments so that
   # the commit queue can handle CLs rolling test_fonts
   # and whatever else without interference from each other.
diff --git a/skia/BUILD.gn b/skia/BUILD.gn
index 9d66524..08fbe4f 100644
--- a/skia/BUILD.gn
+++ b/skia/BUILD.gn
@@ -17,7 +17,7 @@
   import("//build/config/mips.gni")
 }
 
-skia_support_gpu = !is_ios
+skia_use_ganesh_backend = !is_ios
 skia_support_pdf = false
 
 # External-facing config for dependent code.
@@ -40,10 +40,8 @@
     ]
   }
 
-  if (skia_support_gpu) {
-    defines += [ "SK_SUPPORT_GPU=1" ]
-  } else {
-    defines += [ "SK_SUPPORT_GPU=0" ]
+  if (skia_use_ganesh_backend) {
+    defines += [ "SK_GANESH" ]
   }
 
   if (skia_use_gl) {
@@ -196,7 +194,7 @@
   allow_circular_includes_from = [ ":skia_opts" ]
 
   # GPU
-  if (skia_support_gpu) {
+  if (skia_use_ganesh_backend) {
     sources += skia_gpu_public
     sources += skia_gpu_private
     sources += skia_null_gpu_sources
diff --git a/skia/config/SkPdfiumUserConfig.h b/skia/config/SkPdfiumUserConfig.h
index d92b042..e035d09 100644
--- a/skia/config/SkPdfiumUserConfig.h
+++ b/skia/config/SkPdfiumUserConfig.h
@@ -107,14 +107,15 @@
 // #endif
 
 
 /* Determines whether to build code that supports the GPU backend. Some classes
    that are not GPU-specific, such as SkShader subclasses, have optional code
-   that is used allows them to interact with the GPU backend. If you'd like to
-   omit this code set SK_SUPPORT_GPU to 0. This also allows you to omit the gpu
-   directories from your include search path when you're not building the GPU
-   backend. Defaults to 1 (build the GPU code).
- */
-// #define SK_SUPPORT_GPU 1
+   that is used to interact with this GPU backend. If you'd like to
+   include this code, include -DSK_GANESH in your cflags or uncomment below.
+   Defaults to not set (No Ganesh GPU backend).
+   This define affects the ABI of Skia, so make sure it matches the client which uses
+   the compiled version of Skia.
+*/
+// #define SK_GANESH
 
 /* Skia makes use of histogram logging macros to trace the frequency of
  * events. By default, Skia provides no-op versions of these macros.
@@ -107,14 +107,15 @@
 
 
-/* Determines whether to build code that supports the GPU backend. Some classes
+/* Determines whether to build code that supports the Ganesh GPU backend. Some classes
    that are not GPU-specific, such as SkShader subclasses, have optional code